==> devicemaster-linux-7.28.tar.gz: devicemaster-linux-7.28/install.sh <==
#!/bin/bash

KVER="$1"
shift

if [ -z "$KVER" ]; then
    echo "Kernel version to install for must be specified"
    exit 1
fi

if [ -z "$INIT" ]; then
    echo "No INIT system specified, autodetecting..."
    INIT=unknown

    if stat --format='%N' /proc/1/exe | grep -q "/sbin/init" &&
            test -x /sbin/rc &&
            /sbin/rc --version 2>/dev/null | grep -qi openrc; then
        INIT=openrc
    elif stat --format='%N' /proc/1/exe | grep -q "systemd" ||
         { /sbin/init --version 2>/dev/null | grep -q "systemd"; } ; then
        INIT=systemd
    elif stat --format='%N' /proc/1/exe | grep -q "/sbin/init" &&
            test -x /sbin/init &&
            /sbin/init --version 2>/dev/null | grep -qi upstart; then
        INIT=upstart
    elif stat --format='%N' /proc/1/exe | grep -q "/sbin/init" &&
        test -x /sbin/init &&
        test -d /etc/init.d &&
        test -x /sbin/chkconfig; then
        INIT=sysv-chkconfig
    elif stat --format='%N' /proc/1/exe | grep -q "/sbin/init" &&
        test -x /sbin/init &&
        test -d /etc/init.d; then
        if [ -x /usr/sbin/update-rc.d ]; then
            INIT=sysv-update-rc.d
        else
            INIT=sysv-generic
        fi
    fi

    echo "Autodetect init system = $INIT"
fi

if [ -z "$INIT" ]; then
    echo "Couldn't detect INIT system in use"
    exit 1
fi

function do_nslink_install()
{
    echo "Installing nslink tools in /usr/sbin"
    install --mode=700 nslinkadmin      /usr/sbin
    install --mode=700 nslinktool       /usr/sbin
    install --mode=700 nslinkrelease    /usr/sbin
    install --mode=700 nslinkrelease.py /usr/sbin

    echo "Installing nslink daemon in /sbin"
    install --mode=700 nslinkd          /sbin

    echo "Installing man pages in /usr/local/man"
    mkdir -p /usr/local/man/man8 /usr/local/man/man5
    install --mode=644 *8 /usr/local/man/man8/
    install --mode=644 *5 /usr/local/man/man5/

    if [ -f /etc/nslink.conf ]; then
        echo "Using existing configuration file /etc/nslink.conf"
    else
        echo "Creating example config file /etc/nslink.conf, please edit"
        cp nslink.conf /etc/
    fi

    echo "Installing module in /lib/modules/$KVER/misc"
    test -d /lib/modules/$KVER/misc || mkdir /lib/modules/$KVER/misc
    cp nslink.ko /lib/modules/$KVER/misc

    echo -n "Rebuilding module dependencies for kernel $KVER... "
    /sbin/depmod -a -q $KVER
    echo "done"

    WillStart=no
    StartCmd=''

    case "$INIT" in
        openrc)
            echo "Installing for openrc: init script goes in /etc/init.d,"
            echo "using rc-update to enable."
            (set -x
                cp rc.nslink /etc/init.d/nslink
                rc-update add nslink default
            )
	    WillStart=yes
	    StartCmd='/etc/init.d/nslink start'
            ;;

        upstart)
            echo "Installing for upstart: init script goes in /etc/init.d,"
            echo "using update-rc.d to enable"
            (set -x
                cp rc.nslink /etc/init.d/nslink
                update-rc.d nslink defaults 90 10
            )
	    WillStart=yes
	    StartCmd='service nslink start'
            ;;

        sysv-chkconfig)
            echo "Installing for sysv: init script goes in /etc/init.d,"
            echo "using chkconfig to enable"
            (set -x
                cp rc.nslink /etc/init.d/nslink
                chkconfig --add nslink
            )
	    WillStart=yes
	    StartCmd='/etc/init.d/nslink start'
            ;;

        sysv-generic)
            echo "Installing for sysv: init script goes in /etc/init.d,"
            (set -x;  cp rc.nslink /etc/init.d/nslink)
            echo
            echo "don't know how to enable!"
            echo
	    echo "**** you must manually enable startup of daemon ****"
            echo "**** rc script is in /etc/init.d/nslink         ****"
            echo 
	    StartCmd='/etc/init.d/nslink start'
            ;;

        sysv-update-rc.d)
            echo "Installing for sysv with update-rc.d: init script goes in /etc/init.d,"
            (set -x
                cp rc.nslink /etc/init.d/nslink
                update-rc.d nslink defaults 90 10
            )
            if [ -x /usr/sbin/service ]; then
	        StartCmd='service nslink start'
            else
	        StartCmd='/etc/init.d/nslink start'
            fi
            ;;

        systemd)
            echo "Installing for systemd: service file goes in"
            echo "/etc/systemd/system"
            (set -x
            cp nslink.service /etc/systemd/system/
	    systemctl enable nslink
            )
	    WillStart=yes
	    StartCmd='systemctl start nslink'
            ;;

        *)
            echo "***"
	    echo "Don't recognize init system '$INIT'.  Only know how to set up"
            echo "daemon for openrc, upstart, sysv-chkconfig, sysv-generic, and"
            echo "systemd.  Daemon startup must be configured manually.  Daemon"
            echo "is /sbin/nslinkd.  SysV style init script is in this directory"
            echo "as rc.nslink"
	    echo "***"
            exit 1
            ;;
    esac

    if [ "$WillStart" = yes ]; then
        echo 
        echo "NSLink driver and daemon will start after reboot."
        echo
    fi
    if [ "$StartCmd" != "" ]; then
        echo
        echo "To start NSLink driver and daemon now, run this command as root:"
        echo " $StartCmd"
        echo
    fi
}


function do_nslink_uninstall()
{
    echo "Removing nslink tools from /usr/sbin"
    rm -f /usr/sbin/nslinkadmin
    rm -f /usr/sbin/nslinktool       
    rm -f /usr/sbin/nslinkrelease
    rm -f /usr/sbin/nslinkrelease.py

    echo "Removing nslink daemon from /sbin"
    rm -f /sbin/nslinkd

    echo "Removing man pages from /usr/local/man"
    for f in *.8; do rm -f /usr/local/man/man8/$f; done
    for f in *.5; do rm -f /usr/local/man/man5/$f; done

    echo "Removing /etc/nslink.com"
    rm -f /etc/nslink.conf

    echo "Removing modules from /lib/modules/$KVER/misc"
    rm -f /lib/modules/$KVER/misc/nslink.ko

    echo -n "Rebuilding module dependencies for kernel $KVER... "
    /sbin/depmod -a -q $KVER
    echo "done"


    case "$INIT" in
        openrc)
            echo "Uninstalling for openrc: init scripts are in /etc/init.d,"
            echo "using rc-update to disable."
            (set -x
                rc-update del nslink default
                rm -f /etc/init.d/nslink
            )
            ;;

        upstart)
            echo "Uninstalling for upstart: init scripts are in /etc/init.d,"
            echo "using update-rc.d to disable"
            (set -x
                rm -f /etc/init.d/nslink
                update-rc.d -f nslink remove 
            )
            ;;

        sysv-chkconfig)
            echo "Uninstalling for sysv: init scripts are in /etc/init.d,"
            echo "using chkconfig to enable"
            (set -x
                cp rc.nslink /etc/init.d/nslink
                chkconfig --del nslink
            )
            ;;

        sysv-generic)
            (set -x
                rm -f /etc/init.d/nslink
            )
            echo
            echo "Don't know how to disable driver for this Linux distro,"
            echo "You probably need to remove symlinks to /etc/init.d/nslink".
            echo
            ;;

        sysv-update-rc.d)
            echo "Uninstalling for sysv with update-rc.d: init scripts are in /etc/init.d,"
            (set -x
                rm -f /etc/init.d/nslink
                update-rc.d nslink remove
            )
            ;;

        systemd)
            echo "Uninstalling for systemd: service files are in"
            echo "/etc/systemd/system"
            (set -x
	        systemctl disable nslink
                rm -f /etc/systemd/system/nslink.service
            )
            ;;

        *)
            echo "don't recognize init system '$INIT'.  Only know how to uninstall"
            echo "daemon for openrc, upstart, sysv-chkconfig, sysv-generic, and"
            echo "systemd"
            exit 1
            ;;
    esac
}

if [ "$1" = "uninstall" ]; then
    do_nslink_uninstall
else
    do_nslink_install
fi

==> devicemaster-linux-7.34.tar.gz: devicemaster-linux-7.34/install.sh <==
#!/bin/bash

KVER="$1"
shift

if [ -z "$KVER" ]; then
    echo "Kernel version to install for must be specified"
    exit 1
fi

if [ -z "$INIT" ]; then
    echo "No INIT system specified, autodetecting..."
    INIT=unknown

    if stat --format='%N' /proc/1/exe | grep -q "/sbin/init" &&
            test -x /sbin/rc &&
            /sbin/rc --version 2>/dev/null | grep -qi openrc; then
        INIT=openrc
    elif stat --format='%N' /proc/1/exe | grep -q "systemd" ||
         { /sbin/init --version 2>/dev/null | grep -q "systemd"; } ; then
        INIT=systemd
    elif stat --format='%N' /proc/1/exe | grep -q "/sbin/init" &&
            test -x /sbin/init &&
            /sbin/init --version 2>/dev/null | grep -qi upstart; then
        INIT=upstart
    elif stat --format='%N' /proc/1/exe | grep -q "/sbin/init" &&
        test -x /sbin/init &&
        test -d /etc/init.d &&
        test -x /sbin/chkconfig; then
        INIT=sysv-chkconfig
    elif stat --format='%N' /proc/1/exe | grep -q "/sbin/init" &&
        test -x /sbin/init &&
        test -d /etc/init.d; then
        if [ -x /usr/sbin/update-rc.d ]; then
            INIT=sysv-update-rc.d
        else
            INIT=sysv-generic
        fi
    fi

    echo "Autodetect init system = $INIT"
fi

if [ -z "$INIT" ]; then
    echo "Couldn't detect INIT system in use"
    exit 1
fi

# use -Z install option if it's supported
INSTALL=install
if install -Z /dev/null /tmp/nslink-empty-$$ &>/dev/null; then
    INSTALL="install -Z"
fi
rm -f /tmp/nslink-empty-$$
echo "Using '$INSTALL' to install files"

function do_nslink_install()
{
    echo "Installing nslink tools in /usr/sbin"
    $INSTALL --mode=700 nslinkadmin      /usr/sbin
    $INSTALL --mode=700 nslinktool       /usr/sbin
    $INSTALL --mode=700 nslinkrelease    /usr/sbin
    $INSTALL --mode=700 nslinkrelease.py /usr/sbin

    echo "Installing nslink daemon in /sbin"
    $INSTALL --mode=700 nslinkd          /sbin

    echo "Installing man pages in /usr/local/man"
    mkdir -p /usr/local/man/man8 /usr/local/man/man5
    $INSTALL --mode=644 *8 /usr/local/man/man8/
    $INSTALL --mode=644 *5 /usr/local/man/man5/

    if [ -f /etc/nslink.conf ]; then
        echo "Using existing configuration file /etc/nslink.conf"
    else
        echo "Creating example config file /etc/nslink.conf, please edit"
        cp nslink.conf /etc/
    fi

    echo "Installing module in /lib/modules/$KVER/misc"
    test -d /lib/modules/$KVER/misc || mkdir /lib/modules/$KVER/misc
    cp nslink.ko /lib/modules/$KVER/misc

    echo -n "Rebuilding module dependencies for kernel $KVER... "
    /sbin/depmod -a $KVER
    echo "done"

    WillStart=no
    StartCmd=''

    case "$INIT" in
        openrc)
            echo "Installing for openrc: init script goes in /etc/init.d,"
            echo "using rc-update to enable."
            (set -x
                cp rc.nslink /etc/init.d/nslink
                rc-update add nslink default
            )
	    WillStart=yes
	    StartCmd='/etc/init.d/nslink start'
            ;;

        upstart)
            echo "Installing for upstart: init script goes in /etc/init.d,"
            echo "using update-rc.d to enable"
            (set -x
                cp rc.nslink /etc/init.d/nslink
                update-rc.d nslink defaults 90 10
            )
	    WillStart=yes
	    StartCmd='service nslink start'
            ;;

        sysv-chkconfig)
            echo "Installing for sysv: init script goes in /etc/init.d,"
            echo "using chkconfig to enable"
            (set -x
                cp rc.nslink /etc/init.d/nslink
                chkconfig --add nslink
            )
	    WillStart=yes
	    StartCmd='/etc/init.d/nslink start'
            ;;

        sysv-generic)
            echo "Installing for sysv: init script goes in /etc/init.d,"
            (set -x;  cp rc.nslink /etc/init.d/nslink)
            echo
            echo "don't know how to enable!"
            echo
	    echo "**** you must manually enable startup of daemon ****"
            echo "**** rc script is in /etc/init.d/nslink         ****"
            echo 
	    StartCmd='/etc/init.d/nslink start'
            ;;

        sysv-update-rc.d)
            echo "Installing for sysv with update-rc.d: init script goes in /etc/init.d,"
            (set -x
                cp rc.nslink /etc/init.d/nslink
                update-rc.d nslink defaults 90 10
            )
            if [ -x /usr/sbin/service ]; then
	        StartCmd='service nslink start'
            else
	        StartCmd='/etc/init.d/nslink start'
            fi
            ;;

        systemd)
            echo "Installing for systemd: service file goes in"
            echo "/etc/systemd/system"
            (set -x
             $INSTALL --mode=644 nslink.service /etc/systemd/system/
             systemctl daemon-reload
	     systemctl enable nslink
            )
	    WillStart=yes
	    StartCmd='systemctl start nslink'
            ;;

        *)
            echo "***"
	    echo "Don't recognize init system '$INIT'.  Only know how to set up"
            echo "daemon for openrc, upstart, sysv-chkconfig, sysv-generic, and"
            echo "systemd.  Daemon startup must be configured manually.  Daemon"
            echo "is /sbin/nslinkd.  SysV style init script is in this directory"
            echo "as rc.nslink"
	    echo "***"
            exit 1
            ;;
    esac

    if [ "$WillStart" = yes ]; then
        echo 
        echo "NSLink driver and daemon will start after reboot."
        echo
    fi
    if [ "$StartCmd" != "" ]; then
        echo
        echo "To start NSLink driver and daemon now, run this command as root:"
        echo " $StartCmd"
        echo
    fi
}


function do_nslink_uninstall()
{
    echo "Removing nslink tools from /usr/sbin"
    rm -f /usr/sbin/nslinkadmin
    rm -f /usr/sbin/nslinktool       
    rm -f /usr/sbin/nslinkrelease
    rm -f /usr/sbin/nslinkrelease.py

    echo "Removing nslink daemon from /sbin"
    rm -f /sbin/nslinkd

    echo "Removing man pages from /usr/local/man"
    for f in *.8; do rm -f /usr/local/man/man8/$f; done
    for f in *.5; do rm -f /usr/local/man/man5/$f; done

    echo "Removing /etc/nslink.com"
    rm -f /etc/nslink.conf

    echo "Removing modules from /lib/modules/$KVER/misc"
    rm -f /lib/modules/$KVER/misc/nslink.ko

    echo -n "Rebuilding module dependencies for kernel $KVER... "
    /sbin/depmod -a $KVER
    echo "done"


    case "$INIT" in
        openrc)
            echo "Uninstalling for openrc: init scripts are in /etc/init.d,"
            echo "using rc-update to disable."
            (set -x
                rc-update del nslink default
                rm -f /etc/init.d/nslink
            )
            ;;

        upstart)
            echo "Uninstalling for upstart: init scripts are in /etc/init.d,"
            echo "using update-rc.d to disable"
            (set -x
                rm -f /etc/init.d/nslink
                update-rc.d -f nslink remove 
            )
            ;;

        sysv-chkconfig)
            echo "Uninstalling for sysv: init scripts are in /etc/init.d,"
            echo "using chkconfig to enable"
            (set -x
                cp rc.nslink /etc/init.d/nslink
                chkconfig --del nslink
            )
            ;;

        sysv-generic)
            (set -x
                rm -f /etc/init.d/nslink
            )
            echo
            echo "Don't know how to disable driver for this Linux distro,"
            echo "You probably need to remove symlinks to /etc/init.d/nslink".
            echo
            ;;

        sysv-update-rc.d)
            echo "Uninstalling for sysv with update-rc.d: init scripts are in /etc/init.d,"
            (set -x
                rm -f /etc/init.d/nslink
                update-rc.d nslink remove
            )
            ;;

        systemd)
            echo "Uninstalling for systemd: service files are in"
            echo "/etc/systemd/system"
            (set -x
  	        systemctl disable nslink
                # give systemctl time to shut down server before we remove the unit file
                sleep 2 
                rm -f /etc/systemd/system/nslink.service
                systemctl daemon-reload
            )
            ;;

        *)
            echo "don't recognize init system '$INIT'.  Only know how to uninstall"
            echo "daemon for openrc, upstart, sysv-chkconfig, sysv-generic, and"
            echo "systemd"
            exit 1
            ;;
    esac
}

if [ "$1" = "uninstall" ]; then
    do_nslink_uninstall
else
    do_nslink_install
fi
